Package: looking4clusters
Type: Package
Version: 1.2.0
Date: 2025-10-01
Title: Interactive Visualization of scRNA-Seq
Description: Enables the interactive visualization of dimensional
    reduction, clustering, and cell properties for scRNA-Seq results. It
    generates an interactive HTML page using either a numeric matrix,
    SummarizedExperiment, SingleCellExperiment or Seurat objects as input.
    The input data can be projected into two-dimensional representations by
    applying dimensionality reduction methods such as PCA, MDS, t-SNE, UMAP,
    and NMF. Displaying multiple dimensionality reduction results within the
    same interface, with interconnected graphs, provides different perspectives
    that facilitate accurate cell classification. The package also integrates
    unsupervised clustering techniques, whose results that can be viewed
    interactively in the graphical interface. In addition to
    visualization, this interface allows manual selection of groups,
    labeling of cell entities based on processed meta-information,
    generation of new graphs displaying gene expression values for each
    cell, sample identification, and visual comparison of samples and
    clusters.
License: GPL-2 | GPL-3
Depends: R (>= 4.5.0)
Imports: stats, utils, SummarizedExperiment, SingleCellExperiment,
        BiocBaseUtils, jsonlite
Suggests: knitr, rmarkdown, Seurat, parallelDist, uwot, NMF, fpc,
        dendextend, cluster, Rtsne, scRNAseq, Matrix
VignetteBuilder: knitr
NeedsCompilation: no
biocViews: Software, Visualization, DataRepresentation, GeneExpression,
        MultipleComparison, Classification, Clustering
BugReports: https://github.com/BioinfoUSAL/looking4clusters/issues/
URL: https://github.com/BioinfoUSAL/looking4clusters/
Authors@R: c( 
    person("David", "Barrios", email = "metal@usal.es", role = c("aut", "cre"), comment = c(ORCID = "0000-0003-4465-0200")),
    person("Angela", "Villaverde", email = "angelavr@usal.es", role = "aut", comment = c(ORCID = "0000-0002-7337-7218")),
    person("Carlos", "Prieto", email = "cprietos@usal.es", role = "aut", comment = c(ORCID = "0000-0001-8178-9768"))
    )
git_url: https://git.bioconductor.org/packages/looking4clusters
git_branch: RELEASE_3_23
git_last_commit: 3c87dce
git_last_commit_date: 2026-04-28
Repository: Bioconductor 3.23
Date/Publication: 2026-04-28
Packaged: 2026-04-28 22:58:42 UTC; biocbuild
Author: David Barrios [aut, cre] (ORCID:
    <https://orcid.org/0000-0003-4465-0200>),
  Angela Villaverde [aut] (ORCID:
    <https://orcid.org/0000-0002-7337-7218>),
  Carlos Prieto [aut] (ORCID: <https://orcid.org/0000-0001-8178-9768>)
Maintainer: David Barrios <metal@usal.es>
